==> opencascade-6.7.1_2.txz: usr/local/share/doc/opencascade/html/occt_dev_guides__building.js <==
var occt_dev_guides__building =
[
    [ "Building 3rd-party libraries on Windows", "occt_dev_guides__building_3rdparty_windows.html", [
      [ "Introduction", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_1", null ],
      [ "Building Mandatory Third-party Products", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2", [
        [ "Tcl/Tk", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2_1", null ],
        [ "FreeType", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2_2", null ]
      ] ],
      [ "Building Optional Third-party Products", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3", [
        [ "TBB", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3_1", null ],
        [ "gl2ps", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3_2", null ],
        [ "FreeImage", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3_3", null ],
        [ "OpenCL ICD Loader", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_opencl", null ]
      ] ]
    ] ],
    [ "Building 3rd-party libraries on Linux", "occt_dev_guides__building_3rdparty_linux.html", [
      [ "Introduction", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_1", null ],
      [ "Building Mandatory Third-party Products", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2", [
        [ "Tcl/Tk", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_1", [
          [ "Installation from binaries:", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_1_1", null ],
          [ "Installation from sources: Tcl", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_1_2", null ],
          [ "Installation from sources: Tk", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_1_3", null ]
        ] ],
        [ "FreeType", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_2", null ]
      ] ],
      [ "Building Optional Third-party Products", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3", [
        [ "TBB", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_1", null ],
        [ "gl2ps", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_2", null ],
        [ "FreeImage", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_3", null ],
        [ "OpenCL ICD Loader", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_4", null ]
      ] ],
      [ "Installation From Official Repositories", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_4", [
        [ "Debian-based distributives", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_4_1", null ]
      ] ]
    ] ],
    [ "Building 3rd-party libraries on MacOS X", "occt_dev_guides__building_3rdparty_osx.html", [
      [ "Introduction", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_1", null ],
      [ "Building Mandatory Third-party Products", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2", [
        [ "Tcl/Tk 8.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_1", [
          [ "Installation from binaries", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_1_1", null ],
          [ "Installation from sources: Tcl 8.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_1_2", null ],
          [ "Installation from sources: Tk 8.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_1_3", null ]
        ] ],
        [ "FreeType 2.4.10", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_2", null ]
      ] ],
      [ "Building Optional Third-party Products", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3", [
        [ "TBB 3.x or 4.x", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3_1", null ],
        [ "gl2ps 1.3.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3_2", null ],
        [ "FreeImage 3.14.1 or 3.15.x", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3_3", null ]
      ] ]
    ] ],
    [ "Using WOK", "occt_dev_guides__building_wok.html", [
      [ "Installing WOK", "occt_dev_guides__building_wok.html#wok1", [
        [ "Windows", "occt_dev_guides__building_wok.html#wok11", null ],
        [ "Linux", "occt_dev_guides__building_wok.html#wok12", null ],
        [ "Mac OS X", "occt_dev_guides__building_wok.html#wok13", null ]
      ] ],
      [ "Initialization of Workbench", "occt_dev_guides__building_wok.html#wok2", null ],
      [ "Generation of building projects", "occt_dev_guides__building_wok.html#wok3", null ],
      [ "Generation of documentation", "occt_dev_guides__building_wok.html#wok4", null ]
    ] ],
    [ "Building with Automake", "occt_dev_guides__building_automake.html", null ],
    [ "Building with CMake", "occt_dev_guides__building_cmake.html", null ],
    [ "Building with Code::Blocks on Mac OS X", "occt_dev_guides__building_code_blocks.html", null ],
    [ "Building with MS Visual C++", "occt_dev_guides__building_msvc.html", null ],
    [ "Building with Xcode", "occt_dev_guides__building_xcode.html", null ]
];

==> opencascade-6.9.1_1.txz: usr/local/share/doc/opencascade/html/occt_dev_guides__building.js <==
var occt_dev_guides__building =
[
    [ "Building 3rd-party libraries on Windows", "occt_dev_guides__building_3rdparty_windows.html", [
      [ "Introduction", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_1", null ],
      [ "Building Mandatory Third-party Products", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2", [
        [ "Tcl/Tk", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2_1", [
          [ "Installation from sources: Tcl", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2_1_1", null ],
          [ "Installation from sources: Tk", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2_1_2", null ]
        ] ],
        [ "FreeType", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_2_2", null ]
      ] ],
      [ "Building Optional Third-party Products", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3", [
        [ "TBB", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3_1", null ],
        [ "gl2ps", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3_2", null ],
        [ "FreeImage", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3_3", null ],
        [ "VTK", "occt_dev_guides__building_3rdparty_windows.html#dev_guides__building_3rdparty_win_3_4", null ]
      ] ]
    ] ],
    [ "Building 3rd-party libraries on Linux", "occt_dev_guides__building_3rdparty_linux.html", [
      [ "Introduction", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_1", null ],
      [ "Building Mandatory Third-party Products", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2", [
        [ "Tcl/Tk", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_1", [
          [ "Installation from sources: Tcl", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_1_2", null ],
          [ "Installation from sources: Tk", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_1_3", null ]
        ] ],
        [ "FreeType", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_2_2", null ]
      ] ],
      [ "Building Optional Third-party Products", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3", [
        [ "TBB", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_1", null ],
        [ "gl2ps", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_2", null ],
        [ "FreeImage", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_3", null ],
        [ "VTK", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_3_4", null ]
      ] ],
      [ "Installation From Official Repositories", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_4", [
        [ "Debian-based distributives", "occt_dev_guides__building_3rdparty_linux.html#dev_guides__building_3rdparty_linux_4_1", null ]
      ] ]
    ] ],
    [ "Building 3rd-party libraries on MacOS X", "occt_dev_guides__building_3rdparty_osx.html", [
      [ "Introduction", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_1", null ],
      [ "Building Mandatory Third-party Products", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2", [
        [ "Tcl/Tk 8.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_1", [
          [ "Installation from sources: Tcl 8.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_1_2", null ],
          [ "Installation from sources: Tk 8.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_1_3", null ]
        ] ],
        [ "FreeType 2.4.10", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_2_2", null ]
      ] ],
      [ "Building Optional Third-party Products", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3", [
        [ "TBB 3.x or 4.x", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3_1", null ],
        [ "gl2ps 1.3.5", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3_2", null ],
        [ "FreeImage 3.14.1 or 3.15.x", "occt_dev_guides__building_3rdparty_osx.html#dev_guides__building_3rdparty_osx_3_3", null ]
      ] ]
    ] ],
    [ "Using WOK", "occt_dev_guides__building_wok.html", [
      [ "Installing WOK", "occt_dev_guides__building_wok.html#wok1", [
        [ "Windows", "occt_dev_guides__building_wok.html#wok11", null ],
        [ "Linux", "occt_dev_guides__building_wok.html#wok12", null ],
        [ "Mac OS X", "occt_dev_guides__building_wok.html#wok13", null ]
      ] ],
      [ "Initialization of Workbench", "occt_dev_guides__building_wok.html#wok2", null ],
      [ "Generation of building projects", "occt_dev_guides__building_wok.html#wok3", null ],
      [ "Generation of documentation", "occt_dev_guides__building_wok.html#wok4", null ]
    ] ],
    [ "Building with Automake", "occt_dev_guides__building_automake.html", null ],
    [ "Building with CMake", "occt_dev_guides__building_cmake.html", null ],
    [ "Building with CMake and ADT for Android", "occt_dev_guides__building_android.html", null ],
    [ "Building with Code::Blocks on Mac OS X", "occt_dev_guides__building_code_blocks.html", null ],
    [ "Building with MS Visual C++", "occt_dev_guides__building_msvc.html", null ],
    [ "Building with Xcode", "occt_dev_guides__building_xcode.html", null ]
];
